#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2018-03-12
#
# Check Point Eventia metrics plugins
# checkpoint_eva
# checkpoint_eva_db
# checkpoint_eva_jobs
#

from cmk.gui.i18n import _

from cmk.gui.plugins.metrics import (
    metric_info,
    graph_info,
    perfometer_info,
    TB
)


##############################################################################
#
# define metrics for perfdata
#
##############################################################################


metric_info['checkpoint_eva_neweventshandled'] = {
    'title': _('New events'),
    'unit': '1/s',
    'color': '26/a',
}

metric_info['checkpoint_eva_updateshandled'] = {
    'title': _('Updates'),
    'unit': '1/s',
    'color': '21/a',
}

metric_info['checkpoint_eva_numprocessedlogs_sec'] = {
    'title': _('Processed logs'),
    'unit': '1/s',
    'color': '26/a',
}

metric_info['checkpoint_eva_cu_events'] = {
    'title': _('Events'),
    'unit': '1/s',
    'color': '11/a',
}

metric_info['checkpoint_eva_cu_uptime'] = {
    'title': _('Uptime'),
    'unit': 's',
    'color': '21/a',
}

metric_info['checkpoint_eva_db_db_disk_space'] = {
    'title': _('Database disc space free'),
    'unit': 'bytes',
    'color': '21/a',
}

metric_info['checkpoint_eva_db_db_capacity'] = {
    'title': _('Database capacity'),
    'unit': 'bytes',
    'color': '31/a',
}

metric_info['checkpoint_eva_db_db_size'] = {
    'title': _('Database size'),
    'unit': 'bytes',
    'color': '11/a',
}

metric_info['checkpoint_eva_db_dbsize_percent'] = {
    'title': _('Database space used'),
    'unit': '%',
    'color': '26/a',
}


metric_info['checkpoint_eva_db_events_in_db'] = {
    'title': _('Events in Database'),
    'unit': 'count',
    'color': '41/a',
}

metric_info['checkpoint_eva_db_disk_size'] = {
    'title': _('Disk Size'),
    'unit': 'bytes',
    'color': '42/a',
}

metric_info['checkpoint_eva_jobs_analyzed_log'] = {
    'title': _('Analyzed logs'),
    'unit': '1/s',
    'color': '26/a',
}

metric_info['checkpoint_eva_jobs_position_in_file'] = {
    'title': _('Position in file'),
    'unit': 'count',
    'color': '21/a',
}


##############################################################################
#
# how to graph perdata
#
##############################################################################

graph_info['checkpoint_eva_status'] = {
    'title': _('Check Point Eventia Status: Events/Updates'),
    'metrics': [
        ('checkpoint_eva_neweventshandled', 'line'),
        ('checkpoint_eva_updateshandled', '-line'),
    ],
}
graph_info['checkpoint_eva__correlation_unit_status'] = {
    'title': _('Check Point Eventia correlation unit status'),
    'metrics': [
        ('checkpoint_eva_numprocessedlogs_sec', 'line'),
    ],
}

graph_info['checkpoint_eva_db_percent'] = {
    'title': _('Check Point Eventia database space used'),
    'metrics': [
        ('checkpoint_eva_db_dbsize_percent', 'area'),
    ],
    'range': (0, 110),
    'scalars': [
        ('checkpoint_eva_db_dbsize_percent:crit', _('crit')),
        ('checkpoint_eva_db_dbsize_percent:warn', _('warn')),
    ],
}

graph_info['checkpoint_eva_db_disk'] = {
    'title': _('Check Point Eventia Database/Disk'),
    'metrics': [
        ('checkpoint_eva_db_db_size', 'stack'),
        ('checkpoint_eva_db_db_disk_space', 'stack'),
        ('checkpoint_eva_db_db_capacity', 'line'),
        ('checkpoint_eva_db_disk_size', 'line')
    ],
    'range': (0, 'checkpoint_eva_db_disk_size:max'),
}


graph_info['checkpoint_eva_db_events'] = {
    'title': _('Check Point Eventia events in database'),
    'metrics': [
        ('checkpoint_eva_db_events_in_db', 'area'),
    ],
}

graph_info['checkpoint_eva_job_analyzed'] = {
    'title': _('Check Point Eventia Job: Analyzed events'),
    'metrics': [
        ('checkpoint_eva_jobs_analyzed_log', 'line'),
    ],
}

graph_info['checkpoint_eva_job_position'] = {
    'title': _('Check Point Eventia Job: Position in file'),
    'metrics': [
        ('checkpoint_eva_jobs_position_in_file', 'line'),
    ],
}

##############################################################################
#
# define perf-o-meter
#
##############################################################################

perfometer_info.append(('stacked', [
    {
        'type': 'logarithmic',
        'metric': 'checkpoint_eva_neweventshandled',
        'half_value': 1000.0,
        'exponent': 2,
    },
    {
        'type': 'logarithmic',
        'metric': 'checkpoint_eva_updateshandled',
        'half_value': 1000.0,
        'exponent': 2,
    },
]))

perfometer_info.append(('stacked', [
    {
        'type': 'logarithmic',
        'metric': 'checkpoint_eva_cu_uptime',
        'half_value': 2592000.0,
        'exponent': 2,
    },
    {
        'type': 'linear',
        'segments': ['checkpoint_eva_cu_events'],
        'total': 100,
    }
]))

perfometer_info.append(('stacked', [
    {
        'type': 'linear',
        'segments': ['checkpoint_eva_db_dbsize_percent'],
        'total': 100,
    },
    {
        'type': 'logarithmic',
        'metric': 'checkpoint_eva_db_events_in_db',
        'half_value': 100000000.0,
        'exponent': 5,
    },

]))

perfometer_info.append({
        'type': 'logarithmic',
        'metric': 'checkpoint_eva_jobs_analyzed_log',
        'half_value': 100.0,
        'exponent': 2,
})

perfometer_info.append({
        'type': 'logarithmic',
        'metric': 'checkpoint_eva_numprocessedlogs_sec',
        'half_value': 1000.0,
        'exponent': 2,
})